@@ -2,11 +2,19 @@ import base64
 import copy
 from abc import ABC, abstractmethod
 from enum import IntEnum
-from typing import Any, List, Optional, Tuple, TypeVar, Union
+from typing import (
+    Any,
+    List,
+    Dict,
+    Optional,
+    Tuple,
+    TypeVar,
+    Union,
+    cast,
+)
 
-from algosdk import abi, error
+from algosdk import abi, error, transaction
 from algosdk.abi.address_type import AddressType
-from algosdk.future import transaction
 from algosdk.v2client import algod
 
 # The first four bytes of an ABI method call return must have this hash
@@ -37,7 +45,7 @@ class AtomicTransactionComposerStatus(IntEnum):
 
 
 def populate_foreign_array(
-    value_to_add: T, foreign_array: List[T], zero_value: T = None
+    value_to_add: T, foreign_array: List[T], zero_value: Optional[T] = None
 ) -> int:
     """
     Add a value to an application call's foreign array. The addition will be as
@@ -56,10 +64,10 @@ def populate_foreign_array(
             `value_to_add` will not be added to the array and the 0 index will
             be returned.
     """
-    if zero_value and value_to_add == zero_value:
+    if zero_value is not None and value_to_add == zero_value:
         return 0
 
-    offset = 0 if not zero_value else 1
+    offset = 0 if zero_value is None else 1
 
     if value_to_add in foreign_array:
         return foreign_array.index(value_to_add) + offset
@@ -68,6 +76,13 @@ def populate_foreign_array(
     return offset + len(foreign_array) - 1
 
 
+GenericSignedTransaction = Union[
+    transaction.SignedTransaction,
+    transaction.LogicSigTransaction,
+    transaction.MultisigTransaction,
+]
+
+
 class AtomicTransactionComposer:
     """
     Constructs an atomic transaction group which may contain a combination of
@@ -77,7 +92,7 @@ class AtomicTransactionComposer:
         status (AtomicTransactionComposerStatus): IntEnum representing the current state of the composer
         method_dict (dict): dictionary of an index in the transaction list to a Method object
         txn_list (list[TransactionWithSigner]): list of transactions with signers
-        signed_txns (list[SignedTransaction]): list of signed transactions
+        signed_txns (list[GenericSignedTransaction]): list of signed transactions
         tx_ids (list[str]): list of individual transaction IDs in this atomic group
     """
 
@@ -88,10 +103,10 @@ class AtomicTransactionComposer:
 
     def __init__(self) -> None:
         self.status = AtomicTransactionComposerStatus.BUILDING
-        self.method_dict = {}
-        self.txn_list = []
-        self.signed_txns = []
-        self.tx_ids = []
+        self.method_dict: Dict[int, abi.Method] = {}
+        self.txn_list: List[TransactionWithSigner] = []
+        self.signed_txns: List[GenericSignedTransaction] = []
+        self.tx_ids: List[str] = []
 
     def get_status(self) -> AtomicTransactionComposerStatus:
         """
@@ -160,20 +175,22 @@ class AtomicTransactionComposer:
         sender: str,
         sp: transaction.SuggestedParams,
         signer: "TransactionSigner",
-        method_args: List[Union[Any, "TransactionWithSigner"]] = None,
+        method_args: Optional[
+            List[Union[Any, "TransactionWithSigner"]]
+        ] = None,
         on_complete: transaction.OnComplete = transaction.OnComplete.NoOpOC,
-        local_schema: transaction.StateSchema = None,
-        global_schema: transaction.StateSchema = None,
-        approval_program: bytes = None,
-        clear_program: bytes = None,
-        extra_pages: int = None,
-        accounts: List[str] = None,
-        foreign_apps: List[int] = None,
-        foreign_assets: List[int] = None,
-        note: bytes = None,
-        lease: bytes = None,
-        rekey_to: str = None,
-        boxes: List[Tuple[int, bytes]] = None,
+        local_schema: Optional[transaction.StateSchema] = None,
+        global_schema: Optional[transaction.StateSchema] = None,
+        approval_program: Optional[bytes] = None,
+        clear_program: Optional[bytes] = None,
+        extra_pages: Optional[int] = None,
+        accounts: Optional[List[str]] = None,
+        foreign_apps: Optional[List[int]] = None,
+        foreign_assets: Optional[List[int]] = None,
+        note: Optional[bytes] = None,
+        lease: Optional[bytes] = None,
+        rekey_to: Optional[str] = None,
+        boxes: Optional[List[Tuple[int, bytes]]] = None,
     ) -> "AtomicTransactionComposer":
         """
         Add a smart contract method call to this atomic group.
@@ -264,7 +281,7 @@ class AtomicTransactionComposer:
         boxes = boxes[:] if boxes else []
 
         app_args = []
-        raw_values = []
+        raw_values: List[Any] = []
         raw_types = []
         txn_list = []
 
@@ -288,22 +305,24 @@ class AtomicTransactionComposer:
                 txn_list.append(method_args[i])
             else:
                 if abi.is_abi_reference_type(arg.type):
-                    current_type = abi.UintType(8)
+                    current_type: Union[str, abi.ABIType] = abi.UintType(8)
                     if arg.type == abi.ABIReferenceType.ACCOUNT:
                         address_type = AddressType()
                         account_arg = address_type.decode(
-                            address_type.encode(method_args[i])
+                            address_type.encode(
+                                cast(Union[str, bytes], method_args[i])
+                            )
                         )
-                        current_arg = populate_foreign_array(
+                        current_arg: Any = populate_foreign_array(
                             account_arg, accounts, sender
                         )
                     elif arg.type == abi.ABIReferenceType.ASSET:
-                        asset_arg = int(method_args[i])
+                        asset_arg = int(cast(int, method_args[i]))
                         current_arg = populate_foreign_array(
                             asset_arg, foreign_assets
                         )
                     elif arg.type == abi.ABIReferenceType.APPLICATION:
-                        app_arg = int(method_args[i])
+                        app_arg = int(cast(int, method_args[i]))
                         current_arg = populate_foreign_array(
                             app_arg, foreign_apps, app_id
                         )
@@ -398,14 +417,18 @@ class AtomicTransactionComposer:
         An error will be thrown if signing any of the transactions fails.
 
         Returns:
-            list[SignedTransactions]: list of signed transactions
+            List[GenericSignedTransaction]: list of signed transactions
         """
         if self.status >= AtomicTransactionComposerStatus.SIGNED:
             # Return cached versions of the signatures
             return self.signed_txns
 
-        stxn_list = [None] * len(self.txn_list)
-        signer_indexes = {}  # Map a signer to a list of indices to sign
+        stxn_list: List[Optional[GenericSignedTransaction]] = [None] * len(
+            self.txn_list
+        )
+        signer_indexes: Dict[
+            TransactionSigner, List[int]
+        ] = {}  # Map a signer to a list of indices to sign
         txn_list = self.build_group()
         for i, txn_with_signer in enumerate(txn_list):
             if txn_with_signer.signer not in signer_indexes:
@@ -424,12 +447,13 @@ class AtomicTransactionComposer:
             raise error.AtomicTransactionComposerError(
                 "missing signatures, got {}".format(stxn_list)
             )
+        full_stxn_list = cast(List[GenericSignedTransaction], stxn_list)
 
         self.status = AtomicTransactionComposerStatus.SIGNED
-        self.signed_txns = stxn_list
+        self.signed_txns = full_stxn_list
         return self.signed_txns
 
-    def submit(self, client: algod.AlgodClient) -> list:
+    def submit(self, client: algod.AlgodClient) -> List[str]:
         """
         Send the transaction group to the network, but don't wait for it to be
         committed to a block. An error will be thrown if submission fails.
@@ -442,7 +466,7 @@ class AtomicTransactionComposer:
             client (AlgodClient): Algod V2 client
 
         Returns:
-            list[Transaction]: list of submitted transactions
+            List[str]: list of submitted transaction IDs
         """
         if self.status <= AtomicTransactionComposerStatus.SUBMITTED:
             self.gather_signatures()
@@ -496,10 +520,10 @@ class AtomicTransactionComposer:
         method_results = []
 
         for i, tx_id in enumerate(self.tx_ids):
-            raw_value = None
+            raw_value: Optional[bytes] = None
             return_value = None
             decode_error = None
-            tx_info = None
+            tx_info: Optional[Any] = None
 
             if i not in self.method_dict:
                 continue
@@ -511,7 +535,7 @@ class AtomicTransactionComposer:
                     method_results.append(
                         ABIResult(
                             tx_id=tx_id,
-                            raw_value=raw_value,
+                            raw_value=cast(bytes, raw_value),
                             return_value=return_value,
                             decode_error=decode_error,
                             tx_info=tx_info,
@@ -538,18 +562,19 @@ class AtomicTransactionComposer:
                         "app call transaction did not log a return value"
                     )
                 raw_value = result_bytes[4:]
-                return_value = self.method_dict[i].returns.type.decode(
-                    raw_value
+                method_return_type = cast(
+                    abi.ABIType, self.method_dict[i].returns.type
                 )
+                return_value = method_return_type.decode(raw_value)
             except Exception as e:
                 decode_error = e
 
             abi_result = ABIResult(
                 tx_id=tx_id,
-                raw_value=raw_value,
+                raw_value=cast(bytes, raw_value),
                 return_value=return_value,
                 decode_error=decode_error,
-                tx_info=tx_info,
+                tx_info=cast(Any, tx_info),
                 method=self.method_dict[i],
             )
             method_results.append(abi_result)
@@ -572,7 +597,7 @@ class TransactionSigner(ABC):
     @abstractmethod
     def sign_transactions(
         self, txn_group: List[transaction.Transaction], indexes: List[int]
-    ) -> list:
+    ) -> List[GenericSignedTransaction]:
         pass
 
 
@@ -591,7 +616,7 @@ class AccountTransactionSigner(TransactionSigner):
 
     def sign_transactions(
         self, txn_group: List[transaction.Transaction], indexes: List[int]
-    ) -> list:
+    ) -> List[GenericSignedTransaction]:
         """
         Sign transactions in a transaction group given the indexes.
 
@@ -625,7 +650,7 @@ class LogicSigTransactionSigner(TransactionSigner):
 
     def sign_transactions(
         self, txn_group: List[transaction.Transaction], indexes: List[int]
-    ) -> list:
+    ) -> List[GenericSignedTransaction]:
         """
         Sign transactions in a transaction group given the indexes.
 
@@ -637,7 +662,7 @@ class LogicSigTransactionSigner(TransactionSigner):
             txn_group (list[Transaction]): atomic group of transactions
             indexes (list[int]): array of indexes in the atomic transaction group that should be signed
         """
-        stxns = []
+        stxns: List[GenericSignedTransaction] = []
         for i in indexes:
             stxn = transaction.LogicSigTransaction(txn_group[i], self.lsig)
             stxns.append(stxn)
@@ -661,7 +686,7 @@ class MultisigTransactionSigner(TransactionSigner):
 
     def sign_transactions(
         self, txn_group: List[transaction.Transaction], indexes: List[int]
-    ) -> list:
+    ) -> List[GenericSignedTransaction]:
         """
         Sign transactions in a transaction group given the indexes.
 
@@ -673,7 +698,7 @@ class MultisigTransactionSigner(TransactionSigner):
             txn_group (list[Transaction]): atomic group of transactions
             indexes (list[int]): array of indexes in the atomic transaction group that should be signed
         """
-        stxns = []
+        stxns: List[GenericSignedTransaction] = []
         for i in indexes:
             mtxn = transaction.MultisigTransaction(txn_group[i], self.msig)
             for sk in self.sks:
@@ -693,7 +718,7 @@ class TransactionWithSigner:
 class ABIResult:
     def __init__(
         self,
-        tx_id: int,
+        tx_id: str,
         raw_value: bytes,
         return_value: Any,
         decode_error: Optional[Exception],
