@@ -2,10 +2,10 @@ import base64
 import binascii
 import string
 from dataclasses import dataclass
-from typing import List, Union
+from typing import Union, List, Optional
 
 from algosdk.constants import payment_txn, appcall_txn, ZERO_ADDRESS
-from algosdk.future import transaction
+from algosdk import transaction
 from algosdk.encoding import encode_address, msgpack_encode
 from algosdk.v2client.models import (
     DryrunRequest,
@@ -25,7 +25,7 @@ PRINTABLE = frozenset(string.printable)
 class LSig:
     """Logic Sig program parameters"""
 
-    args: List[bytes] = None
+    args: Optional[List[bytes]] = None
 
 
 @dataclass
@@ -33,12 +33,12 @@ class App:
     """Application program parameters"""
 
     creator: str = ZERO_ADDRESS
-    round: int = None
+    round: Optional[int] = None
     app_idx: int = 0
     on_complete: int = 0
-    args: List[bytes] = None
-    accounts: List[Union[str, Account]] = None
-    global_state: List[TealKeyValue] = None
+    args: Optional[List[bytes]] = None
+    accounts: Optional[List[Union[str, Account]]] = None
+    global_state: Optional[List[TealKeyValue]] = None
 
 
 class DryrunTestCaseMixin:
@@ -511,7 +511,7 @@ class Helper:
     ):
         """
         Helper function for creation DryrunRequest object from a program.
-        By default it uses logic sig mode
+        By default, it uses logic sig mode
         and if app_idx / on_complete are set then application call is made
 
         Args:
@@ -621,7 +621,7 @@ class Helper:
         # replacing program with an empty one is OK since it set by source
         # LogicSig does not like None/invalid programs because of validation
         program = program if isinstance(program, bytes) else b"\x01"
-        logicsig = transaction.LogicSig(program, lsig.args)
+        logicsig = transaction.LogicSigAccount(program, lsig.args)
         return transaction.LogicSigTransaction(txn, logicsig)
 
     @staticmethod
